#region Copyright Syncfusion Inc. 2001 - 2005
//
//  Copyright Syncfusion Inc. 2001 - 2005. All rights reserved.
//
//  Use of this code is subject to the terms of our license.
//  A copy of the current license can be obtained at any time by e-mailing
//  licensing@syncfusion.com. Any infringement will be prosecuted under
//  applicable laws. 
//
#endregion

using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;

namespace DropDownFormAndUserControlSample
{
	/// <summary>
	/// Summary description for DropDownForm.
	/// </summary>
	public class DropDownForm : System.Windows.Forms.Form
	{
		private System.Windows.Forms.Panel panel1;
		private System.Windows.Forms.Button okButton;
		private System.Windows.Forms.Button cancelButton;
		private System.Windows.Forms.CheckedListBox checkedListBox1;
		/// <summary>
		/// Required designer variable.
		/// </summary>
		private System.ComponentModel.Container components = null;

		public DropDownForm()
		{
			//
			// Required for Windows Form Designer support
			//
			InitializeComponent();

			// This is the form class that is used in the drop down cell.
			// Besides the CheckedListBox and buttons, it these members added:
			//
			// 1) public method SetValuesFromString that accepts a string and
			//    sets the string to set the CheckedListValues appropriately.
			// 2) public method GetValuesToString that returns the CheckedList
			//    values as a comma separated string.
			// 3) Cancel and OK button event handlers that set the DialogResult 
			//    and closes the form.
			// 4) A KeyDown event handler that cancels the action if the user
			//    presses escape while the form is displayed.
		}

		/// <summary>
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if(components != null)
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		#region Windows Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
			this.panel1 = new System.Windows.Forms.Panel();
			this.cancelButton = new System.Windows.Forms.Button();
			this.okButton = new System.Windows.Forms.Button();
			this.checkedListBox1 = new System.Windows.Forms.CheckedListBox();
			this.panel1.SuspendLayout();
			this.SuspendLayout();
			// 
			// panel1
			// 
			this.panel1.Controls.AddRange(new System.Windows.Forms.Control[] {
																				 this.cancelButton,
																				 this.okButton});
			this.panel1.Dock = System.Windows.Forms.DockStyle.Bottom;
			this.panel1.Location = new System.Drawing.Point(0, 112);
			this.panel1.Name = "panel1";
			this.panel1.Size = new System.Drawing.Size(160, 48);
			this.panel1.TabIndex = 0;
			// 
			// cancelButton
			// 
			this.cancelButton.Anchor = System.Windows.Forms.AnchorStyles.None;
			this.cancelButton.Location = new System.Drawing.Point(8, 16);
			this.cancelButton.Name = "cancelButton";
			this.cancelButton.Size = new System.Drawing.Size(64, 23);
			this.cancelButton.TabIndex = 1;
			this.cancelButton.Text = "Cancel";
			this.cancelButton.Click += new System.EventHandler(this.cancelButton_Click);
			this.cancelButton.KeyDown += new System.Windows.Forms.KeyEventHandler(this.HandleKeyDown);
			// 
			// okButton
			// 
			this.okButton.Anchor = System.Windows.Forms.AnchorStyles.None;
			this.okButton.Location = new System.Drawing.Point(88, 16);
			this.okButton.Name = "okButton";
			this.okButton.Size = new System.Drawing.Size(58, 23);
			this.okButton.TabIndex = 0;
			this.okButton.Text = "OK";
			this.okButton.Click += new System.EventHandler(this.okButton_Click);
			this.okButton.KeyDown += new System.Windows.Forms.KeyEventHandler(this.HandleKeyDown);
			// 
			// checkedListBox1
			// 
			this.checkedListBox1.Dock = System.Windows.Forms.DockStyle.Fill;
			this.checkedListBox1.Items.AddRange(new object[] {
																 "choice1",
																 "choice2",
																 "choice3",
																 "choice4",
																 "choice5",
																 "choice6"});
			this.checkedListBox1.Name = "checkedListBox1";
			this.checkedListBox1.Size = new System.Drawing.Size(160, 109);
			this.checkedListBox1.TabIndex = 1;
			this.checkedListBox1.KeyDown += new System.Windows.Forms.KeyEventHandler(this.HandleKeyDown);
			// 
			// DropDownForm
			// 
			this.AcceptButton = this.okButton;
			this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
			this.ClientSize = new System.Drawing.Size(160, 160);
			this.ControlBox = false;
			this.Controls.AddRange(new System.Windows.Forms.Control[] {
																		  this.checkedListBox1,
																		  this.panel1});
			this.FormBorderStyle = System.Windows.Forms.FormBorderStyle.SizableToolWindow;
			this.Name = "DropDownForm";
			this.ShowInTaskbar = false;
			this.StartPosition = System.Windows.Forms.FormStartPosition.Manual;
			this.KeyDown += new System.Windows.Forms.KeyEventHandler(this.HandleKeyDown);
			this.panel1.ResumeLayout(false);
			this.ResumeLayout(false);

		}
		#endregion

		private char delimeter = ',';

		public void SetValuesFromString(string val)
		{
			string temp = delimeter + val + delimeter; //make everything start and ends with delimiter
			
			for(int i = 0; i < this.checkedListBox1.Items.Count; ++i)
			{
				string s = this.checkedListBox1.Items[i].ToString();
				this.checkedListBox1.SetItemChecked(i, temp.IndexOf(delimeter + s + delimeter) > -1); 
			}
		}

		public string GetValuesToString()
		{
			string val = ""; //make everything stars and ends with delimiter
			int i = 0;
			foreach(object s in this.checkedListBox1.Items)
			{
				if(this.checkedListBox1.GetItemChecked(i))
				{
					if(val.Length > 0)
						val += delimeter;
					val += s.ToString();
				}
				i += 1;
			}
			return val;
		}

		private void cancelButton_Click(object sender, System.EventArgs e)
		{
			this.DialogResult = DialogResult.Cancel;
			this.Close();
		 
		}

		private void okButton_Click(object sender, System.EventArgs e)
		{
			this.DialogResult = DialogResult.OK;
			this.Close();
			 
		}

		private void HandleKeyDown(object sender, System.Windows.Forms.KeyEventArgs e)
		{
			if(e.KeyCode == Keys.Escape || e.KeyCode == Keys.F4)
				this.cancelButton.PerformClick();
		}
	}
}
